@@ -90,4 +90,13 @@ def test_travel_init():
     travel = Travel(datetime(year=2015, month=12, day=18),
                     window=4)
     print(len(travel.dates))
-    assert len(travel.dates) == 3
\ No newline at end of file
+    assert len(travel.dates) == 3
+
+
+def test_utils_download():
+    from text_models.utils import download
+    try:
+        download("fail")
+    except Exception:
+        return
+    assert False
\ No newline at end of file
